#!/bin/sh -norc

################################################################################
# Script de filtrage par port avec log des INPUT / OUTPUT sur eth0             #
#                                                                              #
# Commentaire :                                                                #
#  - Aucune restriction avec lo                                                #
#  - Autorise le ping depuis eth0                                              #
#  - Autorise le ping et le HTTP vers la machine du prsentateur               #
#                                                                              #
# Cr le: 2003/04/01                    Dernire modification le : 2004/04/01 #
################################################################################

MY_IP=`export LC_ALL=C && /sbin/ifconfig eth0 | grep 'inet addr' | cut -d':' -f2 | awk '{print $1}'`
IP_SERVEUR=192.168.1.50

# Initialisation de la table FILTER
iptables -t filter -P INPUT   DROP
iptables -t filter -P FORWARD DROP
iptables -t filter -P OUTPUT  DROP
iptables -t filter -F
iptables -t filter -X


# Initialisation de la table NAT
iptables -t nat -P PREROUTING  ACCEPT
iptables -t nat -P OUTPUT      ACCEPT
iptables -t nat -P POSTROUTING ACCEPT
iptables -t nat -F
iptables -t nat -X


# Initialisation de la table MANGLE
iptables -t mangle -P PREROUTING  ACCEPT
iptables -t mangle -P INPUT       ACCEPT
iptables -t mangle -P FORWARD     ACCEPT
iptables -t mangle -P OUTPUT      ACCEPT
iptables -t mangle -P POSTROUTING ACCEPT
iptables -t mangle -F
iptables -t mangle -X

# Autorise toutes les connexions vers le loopback
iptables -t filter -A INPUT  -i lo -j ACCEPT
iptables -t filter -A OUTPUT -o lo -j ACCEPT

# Autorise les pings entrants et sortant depuis eth0
iptables -t filter -A INPUT  -i eth0 -p icmp -j ACCEPT
iptables -t filter -A OUTPUT -o eth0 -p icmp -j ACCEPT

# Autorise a accder au serveur HTTP du prsentateur
iptables -t filter -A INPUT  -i eth0 -s $IP_SERVEUR -d $MY_IP -p tcp --sport 80 -j ACCEPT
iptables -t filter -A OUTPUT -o eth0 -s $MY_IP -d $IP_SERVEUR -p tcp --dport 80 -j ACCEPT

# Log les connexions INPUT et OUTPUT
iptables -t filter -A INPUT  -i eth0 -j LOG --log-prefix Input-eth0
iptables -t filter -A OUTPUT -o eth0 -j LOG --log-prefix Output-eth0
