#!/bin/sh -norc

################################################################################
# Script de filtrage utilisant le suivi de connexion, avec log (ULOG) des      #
# INPUT / OUTPUT sur eth0                                                      #
#                                                                              #
# Commentaire :                                                                #
#  - Aucune restriction avec lo                                                #
#  - Autorise le ping sortant par eth0                                         #
#  - Autorise le ping, le HTTP et le FTP                                       #
#                                                                              #
# Cr le: 2003/04/01                    Dernire modification le : 2004/04/18 #
################################################################################

#MY_IP=`export LC_ALL=C && /sbin/ifconfig eth0 | grep 'inet addr' | cut -d':' -f2 | awk '{print $1}'`
#IP_SERVEUR=192.168.1.50

# Initialisation de la table FILTER
iptables -t filter -P INPUT   DROP
iptables -t filter -P FORWARD DROP
iptables -t filter -P OUTPUT  DROP
iptables -t filter -F
iptables -t filter -X

# Initialisation de la table NAT
iptables -t nat -P PREROUTING  ACCEPT
iptables -t nat -P OUTPUT      ACCEPT
iptables -t nat -P POSTROUTING ACCEPT
iptables -t nat -F
iptables -t nat -X

# Initialisation de la table MANGLE
iptables -t mangle -P PREROUTING  ACCEPT
iptables -t mangle -P INPUT       ACCEPT
iptables -t mangle -P FORWARD     ACCEPT
iptables -t mangle -P OUTPUT      ACCEPT
iptables -t mangle -P POSTROUTING ACCEPT
iptables -t mangle -F
iptables -t mangle -X

# Charge les modules du conntrack
modprobe ip_conntrack
modprobe ip_conntrack_ftp


# Autorise toutes les connexions vers le loopback
iptables -t filter -A INPUT  -i lo -j ACCEPT
iptables -t filter -A OUTPUT -o lo -j ACCEPT

# Autorise les pings sortants par eth0
iptables -t filter -A OUTPUT -o eth0 -p icmp -m state --state NEW,ESTABLISHED -j ACCEPT

# Autorise a accder aux serveurs HTTP externes
iptables -t filter -A OUTPUT -o eth0 -p tcp --dport 80 -m state --state NEW,ESTABLISHED     -j ACCEPT

# Autorise a accder aux serveurs FTP externes
iptables -t filter -A OUTPUT -o eth0 -p tcp --dport 21 -m state --state NEW,ESTABLISHED     -j ACCEPT

# Autorise les paquets en retour des connexions que nous avons initialises
iptables -t filter -A INPUT  -i eth0 -m state --state ESTABLISHED,RELATED -j ACCEPT

# ENORME PIEGE du FTP en mode actif. Ici, on autorise EN SORTIE plus que le port 21...
iptables -t filter -A OUTPUT -o eth0 -m state --state ESTABLISHED         -j ACCEPT

# BONUS 1 : Accelre la connexion FTP, en laissant passer le service "auth" (trou de scurit potentiel, c'est MAL)
iptables -t filter -A INPUT  -i eth0 -p tcp --dport auth -m state --state NEW,ESTABLISHED -j ACCEPT
iptables -t filter -A OUTPUT -o eth0 -p tcp --sport auth -m state --state ESTABLISHED     -j ACCEPT

# Log les connexions INPUT et OUTPUT
iptables -t filter -A INPUT  -i eth0 -j ULOG --ulog-prefix Input-eth0
iptables -t filter -A OUTPUT -o eth0 -j ULOG --ulog-prefix Output-eth0
