#!/bin/sh -norc

################################################################################
# Script de filtrage utilisant le suivi de connexion                           #
#                                                                              #
# Commentaire :                                                                #
#  - Aucune restriction avec lo                                                #
#  - N'utilise pas l'tat NEW                                                  #
#  - Autorise les communications sortantes "ping", HTTP et FTP                 #
#  - Log les autres connexions                                                 #
#                                                                              #
# Cr le: 2003/04/01                    Dernire modification le : 2004/04/18 #
################################################################################


# Initialisation de la table FILTER

# Rglage des cibles par dfaut
iptables -t filter -P INPUT   DROP
iptables -t filter -P FORWARD DROP
iptables -t filter -P OUTPUT  DROP

# Suppression de toutes les chanes pr-dfinies et utilisateur de la table
iptables -t filter -F
iptables -t filter -X


# Initialisation de la table NAT

# Rglage des cibles par dfaut
iptables -t nat -P PREROUTING  ACCEPT
iptables -t nat -P OUTPUT      ACCEPT
iptables -t nat -P POSTROUTING ACCEPT

# Suppression de toutes les chanes pr-dfinies et utilisateur de la table
iptables -t nat -F
iptables -t nat -X


# Initialisation de la table MANGLE

# Rglage des cibles par dfaut
iptables -t mangle -P PREROUTING  ACCEPT
iptables -t mangle -P INPUT       ACCEPT
iptables -t mangle -P FORWARD     ACCEPT
iptables -t mangle -P OUTPUT      ACCEPT
iptables -t mangle -P POSTROUTING ACCEPT

# Suppression de toutes les chanes pr-dfinies et utilisateur de la table
iptables -t mangle -F
iptables -t mangle -X


# Charge les modules du conntrack
modprobe ip_conntrack
modprobe ip_conntrack_ftp


# Autorise toutes les connexions vers le loopback
iptables -t filter -A INPUT  -i lo -j ACCEPT
iptables -t filter -A OUTPUT -o lo -j ACCEPT


# Autorise les connexions sortantes et inities par notre machine, ainsi que les connexions relatives 

# Supprime tout les paquets mal formats
iptables -t filter -A INPUT  -m state --state INVALID -j DROP
iptables -t filter -A OUTPUT -m state --state INVALID -j DROP

# Autorise les paquets entrants suite a une connexion que nous avons inities
iptables -t filter -A INPUT -i eth0 -m state --state ESTABLISHED,RELATED -j ACCEPT

# Autorise les paquets sortants que nous avons initis, pour les protocols icmp, http et ftp
iptables -t filter -A OUTPUT -o eth0 -p icmp -j ACCEPT
iptables -t filter -A OUTPUT -o eth0 -p tcp --dport http --syn -j ACCEPT
iptables -t filter -A OUTPUT -o eth0 -p tcp --dport 21   --syn -j ACCEPT

# Autorise les paquets sortants qui suivent les connexions que nous avons inities
iptables -t filter -A OUTPUT -o eth0 -m state --state ESTABLISHED,RELATED -j ACCEPT

# BONUS 1 : Accelre la connexion FTP, en laissant passer le service "auth" (trou de scurit potentiel, c'est MAL)
# Remarque : 
#  - Pas de rgle "--state INVALID" au dbut, car celle-ci se trouve dj dans le script
#  - Pas de rgles supplmentaire pour les rponses de notre machine. Celle-ci est dfinie juste au-dessus
iptables -t filter -A INPUT -i eth0 -p tcp --dport auth --syn -j ACCEPT

# Log des autres connexions
iptables -t filter -A INPUT  -j LOG
iptables -t filter -A OUTPUT -j LOG
